pub struct InterceptorNext<'a> { /* private fields */ }Expand description
A consuming handle that invokes the next interceptor exactly once.
Implementations
Sourceimpl InterceptorNext<'_>
impl InterceptorNext<'_>
Sourcepub fn run<'a>(self, context: &'a mut RequestContext) -> PipelineFuture<'a>where
Self: 'a,
pub fn run<'a>(self, context: &'a mut RequestContext) -> PipelineFuture<'a>where
Self: 'a,
Executes the next interceptor or advances to extraction and the handler.